@@ -1,16 +1,16 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 ### BEGIN LICENSE
 # Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
-# This program is free software: you can redistribute it and/or modify it 
-# under the terms of the GNU General Public License version 3, as published 
+# This program is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 3, as published
 # by the Free Software Foundation.
-# 
-# This program is distributed in the hope that it will be useful, but 
-# WITHOUT ANY WARRANTY; without even the implied warranties of 
-# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranties of
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 # PURPOSE.  See the GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License along 
+#
+# You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 ### END LICENSE
 import bs4
@@ -327,6 +327,10 @@ class Util:
 
     @staticmethod
     def check_and_update_metadata(filename):
+        if not Util.is_image(filename):
+            # Skip working on stuff that isn't a picture; part of https://bugs.debian.org/893759
+            return False
+
         try:
             m = VarietyMetadata(filename)
         except Exception:
@@ -519,14 +523,8 @@ class Util:
             return r
         except requests.exceptions.SSLError:
             logger.exception('SSL Error for url %s:' % url)
-            try:
-                from variety.VarietyWindow import VarietyWindow
-                VarietyWindow.get_instance().fix_ssl_dependencies()
-            except Exception:
-                pass
             raise
 
-
     @staticmethod
     def request_write_to(r, f):
         for chunk in r.iter_content(1024):
